@@ -1,24 +1,30 @@
-import logging
+from tuprolog import logger
+
+# noinspection PyUnresolvedReferences
 import jpype
+
+# noinspection PyUnresolvedReferences
 import jpype.imports
 
+# noinspection PyUnresolvedReferences
 from it.unibo.tuprolog.theory.parsing import ClausesParser
+# noinspection PyUnresolvedReferences
 from it.unibo.tuprolog.theory.parsing import ClausesReader
 
+# noinspection PyUnresolvedReferences
 from tuprolog.core import Clause
+# noinspection PyUnresolvedReferences
 from tuprolog.theory import Theory
+# noinspection PyUnresolvedReferences
 from tuprolog.jvmutils import open_file, InputStream, ensure_input_steam
 
+# noinspection PyUnresolvedReferences
 from tuprolog.core.operators import Operator, OperatorSet, DEFAULT_OPERATORS, EMPTY_OPERATORS
 
-from collections.abc import Iterable
-from typing import Union
+from typing import Union, Iterable
 
 
-logging.debug("Loaded JVM classes from it.unibo.tuprolog.theory.parsing.*")
-
-
-def clauses_parser(with_default_operators: bool=True, operators: OperatorSet=None) -> ClausesParser:
+def clauses_parser(with_default_operators: bool = True, operators: OperatorSet = None) -> ClausesParser:
     if operators is None:
         if with_default_operators:
             return ClausesParser.getWithDefaultOperators()
@@ -31,7 +37,7 @@ def clauses_parser(with_default_operators: bool=True, operators: OperatorSet=Non
             return ClausesParser.withOperators(operators)
 
 
-def clauses_reader(with_default_operators: bool=True, operators: OperatorSet=None) -> ClausesReader:
+def clauses_reader(with_default_operators: bool = True, operators: OperatorSet = None) -> ClausesReader:
     if operators is None:
         if with_default_operators:
             return ClausesReader.getWithDefaultOperators()
@@ -46,18 +52,17 @@ def clauses_reader(with_default_operators: bool=True, operators: OperatorSet=Non
 
 DEFAULT_CLAUSES_PARSER = clauses_parser()
 
-
 DEFAULT_CLAUSES_READER = clauses_reader()
 
 
-def parse_theory(string: str, operators: OperatorSet=None) -> Theory:
+def parse_theory(string: str, operators: OperatorSet = None) -> Theory:
     if operators is None:
         return DEFAULT_CLAUSES_PARSER.parseTheory(string)
     else:
         return DEFAULT_CLAUSES_PARSER.parseTheory(string, operators)
 
 
-def parse_clauses(string: str, operators: OperatorSet=None, lazy: bool=True) -> Iterable[Clause]:
+def parse_clauses(string: str, operators: OperatorSet = None, lazy: bool = True) -> Iterable[Clause]:
     if lazy:
         if operators is None:
             return DEFAULT_CLAUSES_PARSER.parseClausesLazily(string)
@@ -70,7 +75,7 @@ def parse_clauses(string: str, operators: OperatorSet=None, lazy: bool=True) ->
             return DEFAULT_CLAUSES_PARSER.parseClauses(string, operators)
 
 
-def read_theory(input: Union[InputStream, str], operators: OperatorSet=None) -> Theory:
+def read_theory(input: Union[InputStream, str], operators: OperatorSet = None) -> Theory:
     input = ensure_input_steam(input)
     if operators is None:
         return DEFAULT_CLAUSES_READER.readTheory(input)
@@ -78,7 +83,7 @@ def read_theory(input: Union[InputStream, str], operators: OperatorSet=None) ->
         return DEFAULT_CLAUSES_READER.readTheory(input, operators)
 
 
-def read_clauses(input: Union[InputStream, str], operators: OperatorSet=None, lazy: bool=True) -> Iterable[Clause]:
+def read_clauses(input: Union[InputStream, str], operators: OperatorSet = None, lazy: bool = True) -> Iterable[Clause]:
     input = ensure_input_steam(input)
     if lazy:
         if operators is None:
@@ -90,3 +95,6 @@ def read_clauses(input: Union[InputStream, str], operators: OperatorSet=None, la
             return DEFAULT_CLAUSES_READER.readClauses(input)
         else:
             return DEFAULT_CLAUSES_READER.readClauses(input, operators)
+
+
+logger.debug("Loaded JVM classes from it.unibo.tuprolog.theory.parsing.*")
