@@ -1,36 +1,39 @@
-import logging
+from tuprolog import logger
+
+# noinspection PyUnresolvedReferences
 import jpype
+# noinspection PyUnresolvedReferences
 import jpype.imports
 
+# noinspection PyUnresolvedReferences
 from it.unibo.tuprolog.unify import Unificator
 
+# noinspection PyUnresolvedReferences
 from tuprolog.core import Term
+
+# noinspection PyUnresolvedReferences
 from tuprolog.core import Substitution
-from tuprolog.pyutils import iterable_or_varargs
-from tuprolog.jvmutils import jiterable, jmap
-
-logging.debug("Loaded JVM classes from it.unibo.tuprolog.unify.*")
 
 
-def strict_unificator(context: Substitution=None) -> Unificator:
+def strict_unificator(context: Substitution = None) -> Unificator:
     if context is None:
         return Unificator.strict()
     else:
         return Unificator.strict(context)
 
 
-def naive_unificator(context: Substitution=None) -> Unificator:
+def naive_unificator(context: Substitution = None) -> Unificator:
     if context is None:
         return Unificator.naive()
     else:
         return Unificator.naive(context)
 
 
-def cached_unificator(unificator: Unificator, cache_size: int=Unificator.DEFAULT_CACHE_CAPACITY) -> Unificator:
+def cached_unificator(unificator: Unificator, cache_size: int = Unificator.DEFAULT_CACHE_CAPACITY) -> Unificator:
     return Unificator.cached(unificator, cache_size)
 
 
-def unificator(context: Substitution=None) -> Unificator:
+def unificator(context: Substitution = None) -> Unificator:
     return cached_unificator(strict_unificator(context))
 
 
@@ -47,3 +50,6 @@ def unify(x: Term, y: Term, occur_check: bool = True) -> Term:
 
 def match(x: Term, y: Term, occur_check: bool = True) -> bool:
     return DEFAULT_UNIFICATOR.match(x, y, occur_check)
+
+
+logger.debug("Loaded JVM classes from it.unibo.tuprolog.unify.*")
